@@ -217,7 +217,7 @@ create_accounts (FeedContext *context,
       char *username_bound;
       
       person = galago_create_person (NULL);
-      username_bound = g_strdup_printf ("%s %s", names[i],
+      username_bound = g_strdup_printf ("%s\n%s", names[i],
                                         context->account_username);
       account = galago_service_create_account (service, person, username_bound);
       g_free (username_bound);
@@ -265,7 +265,7 @@ handle_to_account (FeedContext *context,
      * but not for the rest of the world so we do our own ref counting for it 
      * in order that we don't destroy accounts that still have a presence
      */
-    username_bound = g_strdup_printf ("%s %s", username, context->account_username);
+    username_bound = g_strdup_printf ("%s\n%s", username, context->account_username);
     account = galago_service_create_account (service, person, username_bound);
     g_free (username_bound);
     g_free (username);
